summaryrefslogtreecommitdiff
path: root/src/get_str.c
diff options
context:
space:
mode:
authorzimmerma <zimmerma@280ebfd0-de03-0410-8827-d642c229c3f4>2012-07-26 10:19:46 +0000
committerzimmerma <zimmerma@280ebfd0-de03-0410-8827-d642c229c3f4>2012-07-26 10:19:46 +0000
commitdb17ffbd3c13f587cc2d889d1bb9c5fe678ff91a (patch)
treea0371d8b032879a9dc5239ccba60ccbb4096378a /src/get_str.c
parentfe8a2d0ba085498e3aa238c0d07c9d3607cdee63 (diff)
downloadmpfr-db17ffbd3c13f587cc2d889d1bb9c5fe678ff91a.tar.gz
we use a 77-bit approximation in get_str.c (and not 76-bit)
git-svn-id: svn://scm.gforge.inria.fr/svn/mpfr/trunk@8357 280ebfd0-de03-0410-8827-d642c229c3f4
Diffstat (limited to 'src/get_str.c')
-rw-r--r--src/get_str.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/get_str.c b/src/get_str.c
index 1bd5af1ea..96a681033 100644
--- a/src/get_str.c
+++ b/src/get_str.c
@@ -240,7 +240,7 @@ mpfr_get_str_aux (char *const str, mpfr_exp_t *const exp, mp_limb_t *const r,
/***************************************************************************
* __gmpfr_l2b[b-2][0] is a 23-bit upper approximation to log(b)/log(2), *
* __gmpfr_l2b[b-2][1] is a 76-bit upper approximation to log(2)/log(b). *
* The following code is generated by tests/tl2b (with an argument). *
***************************************************************************/
@@ -2202,7 +2202,7 @@ const __mpfr_struct __gmpfr_l2b[BASE_MAX-1][2] = {
/* returns ceil(e * log2(b)^((-1)^i)), or ... + 1.
For i=0, uses a 23-bit upper approximation to log(beta)/log(2).
- For i=1, uses a 76-bit upper approximation to log(2)/log(beta).
+ For i=1, uses a 77-bit upper approximation to log(2)/log(beta).
Note: this function should be called only in the extended exponent range.
*/
mpfr_exp_t
@@ -240,7 +240,7 @@ mpfr_get_str_aux (char *const str, mpfr_exp_t *const exp, mp_limb_t *const r,
/***************************************************************************
* __gmpfr_l2b[b-2][0] is a 23-bit upper approximation to log(b)/log(2), *
- * __gmpfr_l2b[b-2][1] is a 76-bit upper approximation to log(2)/log(b). *
+ * __gmpfr_l2b[b-2][1] is a 77-bit upper approximation to log(2)/log(b). *
* The following code is generated by tests/tl2b (with an argument). *
***************************************************************************/